@@ -1,4 +1,11 @@
-from pydantic import BaseModel, SecretStr
+from pydantic import BaseModel, SecretStr, BaseSettings
+
+
+class BaseServiceSettings(BaseSettings):
+
+    class Config:
+        env_file = ".env"
+        env_nested_delimiter = "__"
 
 
 class MongoSettings(BaseModel):
